emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] externals/consult 301ba70eac: Fix typos


From: ELPA Syncer
Subject: [elpa] externals/consult 301ba70eac: Fix typos
Date: Sun, 26 Mar 2023 12:57:51 -0400 (EDT)

branch: externals/consult
commit 301ba70eacb8cefa67b7a310ef193f5946a3ce24
Author: Daniel Mendler <mail@daniel-mendler.de>
Commit: Daniel Mendler <mail@daniel-mendler.de>

    Fix typos
---
 consult.el | 38 +++++++++++++++++++-------------------
 1 file changed, 19 insertions(+), 19 deletions(-)

diff --git a/consult.el b/consult.el
index e0bb7bebfc..cb6d8dddda 100644
--- a/consult.el
+++ b/consult.el
@@ -529,10 +529,10 @@ We use invalid characters outside the Unicode range.")
   "Narrowing indicator overlay.")
 
 (defvar consult--gc-threshold (* 64 1024 1024)
-  "Large gc threshold for temporary increase.")
+  "Large GC threshold for temporary increase.")
 
 (defvar consult--gc-percentage 0.5
-  "Large gc percentage for temporary increase.")
+  "Large GC percentage for temporary increase.")
 
 (defvar consult--process-chunk (* 1024 1024)
   "Increase process output chunk size.")
@@ -893,7 +893,7 @@ When no project is found and MAY-PROMPT is non-nil ask the 
user."
     (jit-lock-fontify-now start end)))
 
 (defmacro consult--with-increased-gc (&rest body)
-  "Temporarily increase the gc limit in BODY to optimize for throughput."
+  "Temporarily increase the GC limit in BODY to optimize for throughput."
   (cl-with-gensyms (overwrite)
     `(let* ((,overwrite (> consult--gc-threshold gc-cons-threshold))
             (gc-cons-threshold (if ,overwrite consult--gc-threshold 
gc-cons-threshold))
@@ -902,7 +902,7 @@ When no project is found and MAY-PROMPT is non-nil ask the 
user."
 
 (defmacro consult--slow-operation (message &rest body)
   "Show delayed MESSAGE if BODY takes too long.
-Also temporarily increase the gc limit via `consult--with-increased-gc'."
+Also temporarily increase the GC limit via `consult--with-increased-gc'."
   (declare (indent 1))
   `(with-delayed-message (1 ,message)
      (consult--with-increased-gc
@@ -1029,8 +1029,8 @@ See `consult--tofu-append'."
 ;; We must disambiguate the lines by adding a prefix such that two lines with
 ;; the same text can be distinguished.  In order to avoid matching the line
 ;; number, such that the user can search for numbers with `consult-line', we
-;; encode the line number as characters outside the unicode range.  By doing
-;; that, no accidential matching can occur.
+;; encode the line number as characters outside the Unicode range.  By doing
+;; that, no accidental matching can occur.
 (defun consult--tofu-encode (n)
   "Return tofu-encoded number N as a string.
 Large numbers are encoded as multiple tofu characters."
@@ -1170,7 +1170,7 @@ matches case insensitively."
 
 (defun consult--join-regexps (regexps type)
   "Join REGEXPS of TYPE."
   ;; Add lookahead wrapper only if there is more than one regular expression
   (cond
    ((and (eq type 'pcre) (cdr regexps))
     (concat "^" (mapconcat (lambda (x) (format "(?=.*%s)" x))
@@ -1220,7 +1220,7 @@ ESC is the escaping string for choice and groups."
   (assoc selected candidates))
 
 (defun consult--lookup-cdr (selected candidates &rest _)
-  "Lookup SELECTED in CANDIDATES alist, return cdr of element."
+  "Lookup SELECTED in CANDIDATES alist, return `cdr' of element."
   (cdr (assoc selected candidates)))
 
 (defun consult--lookup-location (selected candidates &rest _)
@@ -2205,7 +2205,7 @@ PROPS are optional properties passed to `make-process'."
         (_ (funcall async action))))))
 
 (defun consult--async-highlight (async builder)
-  "Return ASYNC function which highlightes the candidates.
+  "Return ASYNC function which highlights the candidates.
 BUILDER is the command line builder function."
   (let (highlight)
     (lambda (action)
@@ -2500,7 +2500,7 @@ PREVIEW-KEY are the preview keys."
       ;; in the interpreter.  This will make closures and the lambda string
       ;; representation larger, which makes debugging much worse.  Fortunately
       ;; the overcapturing problem does not affect the bytecode interpreter
-      ;; which does a proper scope analyis.
+      ;; which does a proper scope analysis.
       (let* ((metadata `(metadata
                          ,@(when category `((category . ,category)))
                          ,@(when group `((group-function . ,group)))
@@ -3198,7 +3198,7 @@ The symbol at point is added to the future history."
    (consult--global-mark-candidates
     (or markers global-mark-ring))
    :prompt "Go to global mark: "
-   ;; Despite `consult-global-mark' formating the candidates in grep-like
+   ;; Despite `consult-global-mark' formatting the candidates in grep-like
    ;; style, we are not using the 'consult-grep category, since the candidates
    ;; have location markers attached.
    :category 'consult-location
@@ -3437,7 +3437,7 @@ to `consult--buffer-query'."
         ;; No undo recording, modification hooks, buffer modified-status
         (with-silent-modifications (funcall replace content-orig point-orig)))
       ;; Committing or new input provided -> Update
-      (when (and input ;; Input has been povided
+      (when (and input ;; Input has been provided
                  (or
                   ;; Committing, but not with empty input
                   (and (eq action 'return) (not (string-match-p "\\`!? ?\\'" 
input)))
@@ -3481,7 +3481,7 @@ to `consult--buffer-query'."
 The selected lines are kept and the other lines are deleted.  When called
 interactively, the lines selected are those that match the minibuffer input.  
In
 order to match the inverse of the input, prefix the input with `! '.  When
-called from elisp, the filtering is performed by a FILTER function.  This
+called from Elisp, the filtering is performed by a FILTER function.  This
 command obeys narrowing.
 
 FILTER is the filter function.
@@ -3580,7 +3580,7 @@ INITIAL is the initial input."
           (consult-focus-lines 'show)
           (goto-char pt-orig))
          (t
-          ;; Sucessfully terminated -> Remember invisible overlays
+          ;; Successfully terminated -> Remember invisible overlays
           (setq consult--focus-lines-overlays
                 (nconc consult--focus-lines-overlays overlays))
           ;; move point past invisible
@@ -3598,7 +3598,7 @@ The selected lines are shown and the other lines hidden.  
When called
 interactively, the lines selected are those that match the minibuffer input.  
In
 order to match the inverse of the input, prefix the input with `! '.  With
 optional prefix argument SHOW reveal the hidden lines.  Alternatively the
-command can be restarted to reveal the lines.  When called from elisp, the
+command can be restarted to reveal the lines.  When called from Elisp, the
 filtering is performed by a FILTER function.  This command obeys narrowing.
 
 FILTER is the filter function.
@@ -4604,7 +4604,7 @@ configuration of the virtual buffer sources."
 (defmacro consult--with-project (&rest body)
   "Ensure that BODY is executed with a project root."
   ;; We have to work quite hard here to ensure that the project root is
-  ;; only overriden at the current recursion level.  When entering a
+  ;; only overridden at the current recursion level.  When entering a
   ;; recursive minibuffer session, we should be able to still switch the
   ;; project.  But who does that? Working on the first level on project A
   ;; and on the second level on project B and on the third level on project C?
@@ -4728,7 +4728,7 @@ Take the variables `grep-find-ignored-directories' and
 
 MAKE-BUILDER is the function that returns the command line
 builder function.  DIR is a directory or a list of file or
-directories.  PROMPT is the prompt string.  INITIAL is inital
+directories.  PROMPT is the prompt string.  INITIAL is initial
 input."
   (pcase-let* ((`(,prompt ,paths ,dir) (consult--directory-prompt prompt dir))
                (default-directory dir)
@@ -4749,7 +4749,7 @@ input."
      :sort nil)))
 
 (defun consult--grep-lookahead-p (&rest cmd)
-  "Return t if grep CMD supports lookahead."
+  "Return t if grep CMD supports look-ahead."
   (with-temp-buffer
     (insert "xaxbx")
     (eq 0 (apply #'call-process-region (point-min) (point-max)
@@ -4891,7 +4891,7 @@ The filename at point is added to the future history.
 
 BUILDER is the command line builder function.
 PROMPT is the prompt.
-INITIAL is inital input."
+INITIAL is initial input."
   (consult--read
    (consult--async-command builder
      (consult--async-map (lambda (x) (string-remove-prefix "./" x)))
@@ -1170,7 +1170,7 @@ matches case insensitively."
 (defun consult--join-regexps (regexps type)
   "Join REGEXPS of TYPE."
-  ;; Add lookahead wrapper only if there is more than one regular expression
+  ;; Add look-ahead wrapper only if there is more than one regular expression
   (cond
    ((and (eq type 'pcre) (cdr regexps))



reply via email to

[Prev in Thread] Current Thread [Next in Thread]